autowisp.processing_steps.add_images_to_db module — AutoWISP documentation

# autowisp.processing_steps.add_images_to_db module

## Class Inheritance Diagram

Register new images with the database.

autowisp.processing_steps.add_images_to_db._match_observatory(db_observatory, image_location)

  True iff the observatory matches the image location.

autowisp.processing_steps.add_images_to_db.add_images_to_db(image_collection, configuration)

  Add all the images in the collection to the database.

autowisp.processing_steps.add_images_to_db.create_image(image_fname, header_eval, configuration, db_session)

  Create the database Image entry corresponding to the given file.

autowisp.processing_steps.add_images_to_db.get_observatory(header_eval, configuration, db_session)

  Return the observatory corresponding to the image (must exist).

autowisp.processing_steps.add_images_to_db.get_or_create_observing_session(image_type, header_eval, configuration, db_session)

  Return the observing session the image is part of (create if needed).

autowisp.processing_steps.add_images_to_db.get_or_create_target(image_type, header_eval, configuration, db_session, field_of_view)

  Return the target corresponding to the image (create if necessary).

autowisp.processing_steps.add_images_to_db.parse_command_line(*args)

  Return the parsed command line arguments.